==> haskell-hspec-smallcheck-0.5.2-25-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-hspec-smallcheck.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hspec-smallcheck
version: 0.5.2
id: hspec-smallcheck-0.5.2-GFkFkoeCZ9iLyYyBu8vnm
key: hspec-smallcheck-0.5.2-GFkFkoeCZ9iLyYyBu8vnm
license: MIT
copyright: (c) 2013-2018 Simon Hengel
maintainer: Simon Hengel <sol@typeful.net>
homepage: http://hspec.github.io/
synopsis: SmallCheck support for the Hspec testing framework
description:
    SmallCheck support for the Hspec testing framework
category: Testing
abi: 70e988cf3dd0bab2a29549c46e60ddb0
exposed: True
exposed-modules:
    Test.Hspec.SmallCheck
hidden-modules: Test.Hspec.SmallCheck.Compat
                Test.Hspec.SmallCheck.Types Paths_hspec_smallcheck
import-dirs: /usr/lib/ghc-8.4.3/site-local/hspec-smallcheck-0.5.2
library-dirs: /usr/lib/ghc-8.4.3/site-local/hspec-smallcheck-0.5.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/hspec-smallcheck-0.5.2
hs-libraries: HShspec-smallcheck-0.5.2-GFkFkoeCZ9iLyYyBu8vnm
depends:
    HUnit-1.6.0.0-8OmbxYW4AG9PppbZs26Xx base-4.11.1.0
    call-stack-0.1.0-Eiz5FM8yQXpI3vyQ1Rt4Jq
    hspec-core-2.5.5-5n22zQsRnLqHZxe5b65ekh
    smallcheck-1.1.5-3f5qiJxrEExLmWHgkqVfWS
abi-depends: HUnit-1.6.0.0-8OmbxYW4AG9PppbZs26Xx=6ff9610fd5e59ec310c47074d0590847
             base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             call-stack-0.1.0-Eiz5FM8yQXpI3vyQ1Rt4Jq=c76ca250c7cf6b5c2ee744c15760c93f
             hspec-core-2.5.5-5n22zQsRnLqHZxe5b65ekh=32c12a71e80fa56582a73b70dff01188
             smallcheck-1.1.5-3f5qiJxrEExLmWHgkqVfWS=aec4190e63046da29e6cea1cb38a365c
haddock-interfaces: /usr/share/doc/haskell-hspec-smallcheck/html/hspec-smallcheck.haddock
haddock-html: /usr/share/doc/haskell-hspec-smallcheck/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hspec-smallcheck-0.5.2-28-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-hspec-smallcheck.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hspec-smallcheck
version: 0.5.2
id: hspec-smallcheck-0.5.2-DWhbhp1khoK7d1oJkdrzbd
key: hspec-smallcheck-0.5.2-DWhbhp1khoK7d1oJkdrzbd
license: MIT
copyright: (c) 2013-2018 Simon Hengel
maintainer: Simon Hengel <sol@typeful.net>
homepage: http://hspec.github.io/
synopsis: SmallCheck support for the Hspec testing framework
description:
    SmallCheck support for the Hspec testing framework
category: Testing
abi: 34761497c5a8831556106b3901da682c
exposed: True
exposed-modules:
    Test.Hspec.SmallCheck
hidden-modules: Test.Hspec.SmallCheck.Compat
                Test.Hspec.SmallCheck.Types Paths_hspec_smallcheck
import-dirs: /usr/lib/ghc-8.6.1/site-local/hspec-smallcheck-0.5.2
library-dirs: /usr/lib/ghc-8.6.1/site-local/hspec-smallcheck-0.5.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.6.1/hspec-smallcheck-0.5.2
hs-libraries: HShspec-smallcheck-0.5.2-DWhbhp1khoK7d1oJkdrzbd
depends:
    HUnit-1.6.0.0-Kc3RXVOuMSQ9Y4PmNrdWEj base-4.12.0.0
    call-stack-0.1.0-J1eWgTNOnM4IGVyeW0v2YZ
    hspec-core-2.5.5-L3I0MZQ3aCCDiQnLDqJabp
    smallcheck-1.1.5-2tBCkWD6U2LTuxNl0Itl4
haddock-interfaces: /usr/share/doc/haskell-hspec-smallcheck/html/hspec-smallcheck.haddock
haddock-html: /usr/share/doc/haskell-hspec-smallcheck/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
